@@ -9,7 +9,6 @@
 #include <ApplicationAddonsModel.h>
 #include <Category/Category.h>
 #include <Category/CategoryModel.h>
-#include <QAction>
 #include <QQmlContext>
 #include <QQmlEngine>
 #include <ReviewsBackend/AbstractReviewsBackend.h>
@@ -30,15 +29,6 @@
 #include <resources/ResourcesUpdatesModel.h>
 #include <resources/SourcesModel.h>
 
-void DiscoverDeclarativePlugin::initializeEngine(QQmlEngine *engine, const char *uri)
-{
-    engine->rootContext()->setContextProperty(QStringLiteral("ResourcesModel"), ResourcesModel::global());
-    engine->rootContext()->setContextProperty(QStringLiteral("TransactionModel"), TransactionModel::global());
-    engine->rootContext()->setContextProperty(QStringLiteral("SourcesModel"), SourcesModel::global());
-    engine->rootContext()->setContextProperty(QStringLiteral("CategoryModel"), CategoryModel::global());
-    QQmlExtensionPlugin::initializeEngine(engine, uri);
-}
-
 void DiscoverDeclarativePlugin::registerTypes(const char * /*uri*/)
 {
     qmlRegisterType<TransactionListener>("org.kde.discover", 2, 0, "TransactionListener");
@@ -52,18 +42,22 @@ void DiscoverDeclarativePlugin::registerTypes(const char * /*uri*/)
     qmlRegisterType<ReadFile>("org.kde.discover", 2, 0, "ReadFile");
 
     qmlRegisterUncreatableType<DiscoverAction>("org.kde.discover", 2, 0, "DiscoverAction", QStringLiteral("Use QQC Action"));
-    qmlRegisterUncreatableType<QAction>("org.kde.discover", 2, 0, "QAction", QStringLiteral("Use QQC Action"));
     qmlRegisterUncreatableType<AbstractResource>("org.kde.discover", 2, 0, "AbstractResource", QStringLiteral("should come from the ResourcesModel"));
     qmlRegisterUncreatableType<AbstractSourcesBackend>("org.kde.discover", 2, 0, "AbstractSourcesBackend", QStringLiteral("should come from the SourcesModel"));
     qmlRegisterUncreatableType<Transaction>("org.kde.discover", 2, 0, "Transaction", QStringLiteral("should come from the backends"));
     qmlRegisterUncreatableType<SourcesModel>("org.kde.discover", 2, 0, "SourcesModelClass", QStringLiteral("should come from the backends"));
-    qmlRegisterUncreatableType<SourcesModel>("org.kde.discover", 2, 0, "AbstractBackendUpdater", QStringLiteral("should come from the backends"));
+    qmlRegisterUncreatableType<AbstractBackendUpdater>("org.kde.discover", 2, 0, "AbstractBackendUpdater", QStringLiteral("should come from the backends"));
+    qmlRegisterUncreatableType<HelpfulError>("org.kde.discover", 2, 0, "HelpfulError", QStringLiteral("should come from the backend"));
     qmlRegisterAnonymousType<TransactionModel>("org.kde.discover", 1);
     qmlRegisterAnonymousType<Rating>("org.kde.discover", 1);
     qmlRegisterAnonymousType<AbstractResourcesBackend>("org.kde.discover", 1);
     qmlRegisterAnonymousType<AbstractReviewsBackend>("org.kde.discover", 1);
     qmlRegisterAnonymousType<Category>("org.kde.discover", 1);
     qmlRegisterAnonymousType<ResourcesModel>("org.kde.discover", 1);
+    qmlRegisterSingletonInstance("org.kde.discover", 2, 0, "CategoryModel", CategoryModel::global());
+    qmlRegisterSingletonInstance("org.kde.discover", 2, 0, "ResourcesModel", ResourcesModel::global());
+    qmlRegisterSingletonInstance("org.kde.discover", 2, 0, "TransactionModel", TransactionModel::global());
+    qmlRegisterSingletonInstance("org.kde.discover", 2, 0, "SourcesModel", SourcesModel::global());
+
     qmlProtectModule("org.kde.discover", 2);
-    qRegisterMetaType<QList<QAction *>>();
 }
