@@ -26,6 +26,8 @@
 #include "libdiscover_backend_debug.h"
 #include "pk-offline-private.h"
 
+using namespace std::chrono_literals;
+
 PackageKitNotifier::PackageKitNotifier(QObject *parent)
     : BackendNotifierModule(parent)
     , m_securityUpdates(0)
@@ -40,18 +42,18 @@ PackageKitNotifier::PackageKitNotifier(QObject *parent)
     });
 
     // Check if there's packages after 5'
-    QTimer::singleShot(5 * 60 * 1000, this, &PackageKitNotifier::refreshDatabase);
+    QTimer::singleShot(5min, this, &PackageKitNotifier::refreshDatabase);
 
     QTimer *regularCheck = new QTimer(this);
     connect(regularCheck, &QTimer::timeout, this, &PackageKitNotifier::refreshDatabase);
 
     const QString aptconfig = QStandardPaths::findExecutable(QStringLiteral("apt-config"));
     if (!aptconfig.isEmpty()) {
-        checkAptVariable(aptconfig, QLatin1String("Apt::Periodic::Update-Package-Lists"), [regularCheck](const QStringRef &value) {
+        checkAptVariable(aptconfig, QLatin1String("Apt::Periodic::Update-Package-Lists"), [regularCheck](const QStringView &value) {
             bool ok;
             const int days = value.toInt(&ok);
             if (!ok || days == 0) {
-                regularCheck->setInterval(24 * 60 * 60 * 1000); // refresh at least once every day
+                regularCheck->setInterval(24h); // refresh at least once every day
                 regularCheck->start();
                 if (!value.isEmpty())
                     qWarning() << "couldn't understand value for timer:" << value;
@@ -61,11 +63,11 @@ PackageKitNotifier::PackageKitNotifier(QObject *parent)
             // https://wiki.debian.org/UnattendedUpgrades
         });
     } else {
-        regularCheck->setInterval(24 * 60 * 60 * 1000); // refresh at least once every day
+        regularCheck->setInterval(24h); // refresh at least once every day
         regularCheck->start();
     }
 
-    QTimer::singleShot(3000, this, &PackageKitNotifier::checkOfflineUpdates);
+    QTimer::singleShot(3s, this, &PackageKitNotifier::checkOfflineUpdates);
 
     m_recheckTimer = new QTimer(this);
     m_recheckTimer->setInterval(200);
@@ -270,11 +272,11 @@ void PackageKitNotifier::refreshDatabase()
     }
 }
 
-QProcess *PackageKitNotifier::checkAptVariable(const QString &aptconfig, const QLatin1String &varname, const std::function<void(const QStringRef &val)> &func)
+QProcess *PackageKitNotifier::checkAptVariable(const QString &aptconfig, const QLatin1String &varname, const std::function<void(const QStringView &val)> &func)
 {
     QProcess *process = new QProcess;
     process->start(aptconfig, {QStringLiteral("dump")});
-    connect(process, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, [func, process, varname](int code) {
+    connect(process, qOverload<int, QProcess::ExitStatus>(&QProcess::finished), this, [func, process, varname](int code) {
         if (code != 0)
             return;
 
@@ -284,13 +286,13 @@ QProcess *PackageKitNotifier::checkAptVariable(const QString &aptconfig, const Q
         while (stream.readLineInto(&line)) {
             const auto match = rx.match(line);
             if (match.hasMatch()) {
-                func(match.capturedRef(1));
+                func(match.capturedView(1));
                 return;
             }
         }
         func({});
     });
-    connect(process, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), process, &QObject::deleteLater);
+    connect(process, qOverload<int, QProcess::ExitStatus>(&QProcess::finished), process, &QObject::deleteLater);
     return process;
 }
 
