@@ -51,7 +51,6 @@ RpmOstreeResource::RpmOstreeResource(const QVariantMap &map, RpmOstreeBackend *p
         // We can directly read the pretty name & variant from os-release
         // information if this is the currently booted deployment.
         auto osrelease = AppStreamIntegration::global()->osRelease();
-        m_prettyname = osrelease->prettyName();
         m_name = osrelease->name();
         m_variant = osrelease->variant();
     }
@@ -227,21 +226,22 @@ QUrl RpmOstreeResource::donationURL()
 
 QUrl RpmOstreeResource::homepage()
 {
-    return QUrl("https://spins.fedoraproject.org/en/kde/");
+    return QUrl(AppStreamIntegration::global()->osRelease()->homeUrl());
 }
 
 QUrl RpmOstreeResource::helpURL()
 {
-    return QUrl("https://docs.fedoraproject.org/en-US/fedora-kinoite/");
+    return QUrl(AppStreamIntegration::global()->osRelease()->documentationUrl());
 }
 
 QUrl RpmOstreeResource::bugURL()
 {
-    return QUrl("https://pagure.io/fedora-kde/SIG/issues");
+    return QUrl(AppStreamIntegration::global()->osRelease()->bugReportUrl());
 }
 
 QJsonArray RpmOstreeResource::licenses()
 {
+    // TODO: Remove hardcoded value
     return {QJsonObject{{QStringLiteral("name"), i18n("GPL and other licenses")},
                         {QStringLiteral("url"), QStringLiteral("https://fedoraproject.org/wiki/Legal:Licenses")}}};
 }
@@ -253,20 +253,12 @@ QString RpmOstreeResource::longDescription()
 
 QString RpmOstreeResource::name() const
 {
-    // If we are the currently booted deployment then we have a pretty name
-    if (m_prettyname != "") {
-        return m_prettyname;
-    }
-    // Otherwise construct one from what we have
-    // TODO: Remove hardcoded values
-    QString name;
-    QTextStream(&name) << "Fedora Linux " << m_version << " (Kinoite)";
-    return name;
+    return QStringLiteral("%1 %2").arg(packageName(), m_version);
 }
 
 QString RpmOstreeResource::origin() const
 {
-    return QStringLiteral("rpm-ostree");
+    return m_remote;
 }
 
 QString RpmOstreeResource::packageName() const
@@ -298,21 +290,21 @@ QString RpmOstreeResource::comment()
     return i18n("Installed but not currently running version of %1.", packageName());
 }
 
-int RpmOstreeResource::size()
+quint64 RpmOstreeResource::size()
 {
     return 0;
 }
 
+QString RpmOstreeResource::sizeDescription()
+{
+    return QStringLiteral("Unknown");
+}
+
 QDate RpmOstreeResource::releaseDate() const
 {
     return m_timestamp;
 }
 
-QString RpmOstreeResource::executeLabel() const
-{
-    return {};
-}
-
 void RpmOstreeResource::setState(AbstractResource::State state)
 {
     m_state = state;
