@@ -9,13 +9,14 @@
 
 #include "AbstractSourcesBackend.h"
 #include "discovercommon_export.h"
-#include <KConcatenateRowsProxyModel>
 #include <QAbstractListModel>
+#include <QConcatenateTablesProxyModel>
 #include <QSet>
 
-class DISCOVERCOMMON_EXPORT SourcesModel : public KConcatenateRowsProxyModel
+class DISCOVERCOMMON_EXPORT SourcesModel : public QConcatenateTablesProxyModel
 {
     Q_OBJECT
+    Q_PROPERTY(QVector<AbstractSourcesBackend *> sources READ sources NOTIFY sourcesChanged)
 public:
     enum Roles {
         SourceNameRole = AbstractSourcesBackend::LastRole,
@@ -35,8 +36,9 @@ public:
     void addSourcesBackend(AbstractSourcesBackend *sources);
 
     Q_SCRIPTABLE AbstractSourcesBackend *sourcesBackendByName(const QString &name) const;
-
+    QVector<AbstractSourcesBackend *> sources() const;
 Q_SIGNALS:
+    void sourcesChanged();
     void showingNow();
 
 private:
